"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .schema4 import Schema4, Schema4TypedDict
from kombo.types import BaseModel
from typing import Dict
from typing_extensions import TypedDict


class PostHrisEmployeesFormRequestBodyTypedDict(TypedDict):
    properties: Dict[str, Schema4TypedDict]


class PostHrisEmployeesFormRequestBody(BaseModel):
    properties: Dict[str, Schema4]
