"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .postatsapplicationsapplicationidnotesrequestbody import (
    PostAtsApplicationsApplicationIDNotesRequestBody,
    PostAtsApplicationsApplicationIDNotesRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostAtsApplicationsApplicationIDNotesGlobalsTypedDict(TypedDict):
    integration_id: NotRequired[str]
    r"""ID of the integration you want to interact with."""


class PostAtsApplicationsApplicationIDNotesGlobals(BaseModel):
    integration_id: Annotated[
        Optional[str],
        pydantic.Field(alias="X-Integration-Id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""ID of the integration you want to interact with."""


class PostAtsApplicationsApplicationIDNotesRequestTypedDict(TypedDict):
    application_id: str
    r"""The Kombo ID of the application you want to create the note for."""
    body: PostAtsApplicationsApplicationIDNotesRequestBodyTypedDict
    r"""POST /ats/applications/:application_id/notes Request body"""


class PostAtsApplicationsApplicationIDNotesRequest(BaseModel):
    application_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The Kombo ID of the application you want to create the note for."""

    body: Annotated[
        PostAtsApplicationsApplicationIDNotesRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""POST /ats/applications/:application_id/notes Request body"""
