"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetConnectIntegrationByTokenTokenRequestTypedDict(TypedDict):
    token: str
    r"""GET /connect/integration-by-token/:token Parameter"""


class GetConnectIntegrationByTokenTokenRequest(BaseModel):
    token: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""GET /connect/integration-by-token/:token Parameter"""
