"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Dict, List, Union
from typing_extensions import TypeAliasType


Schema4TypedDict = TypeAliasType(
    "Schema4TypedDict",
    Union[str, float, bool, Dict[str, "Schema4TypedDict"], List["Schema4TypedDict"]],
)


Schema4 = TypeAliasType(
    "Schema4", Union[str, float, bool, Dict[str, "Schema4"], List["Schema4"]]
)
