"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .patchintegrationsintegrationidintegrationfieldsintegrationfieldidrequestbody import (
    PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBody,
    PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestTypedDict(
    TypedDict
):
    integration_id: str
    r"""PATCH /integrations/:integration_id/integration-fields/:integration_field_id Parameter"""
    integration_field_id: str
    r"""PATCH /integrations/:integration_id/integration-fields/:integration_field_id Parameter"""
    body: PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBodyTypedDict
    r"""PATCH /integrations/:integration_id/integration-fields/:integration_field_id Request body"""


class PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequest(
    BaseModel
):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""PATCH /integrations/:integration_id/integration-fields/:integration_field_id Parameter"""

    integration_field_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""PATCH /integrations/:integration_id/integration-fields/:integration_field_id Parameter"""

    body: Annotated[
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""PATCH /integrations/:integration_id/integration-fields/:integration_field_id Request body"""
