"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .deletehrisabsencesabsenceidrequestbody import (
    DeleteHrisAbsencesAbsenceIDRequestBody,
    DeleteHrisAbsencesAbsenceIDRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteHrisAbsencesAbsenceIDGlobalsTypedDict(TypedDict):
    integration_id: NotRequired[str]
    r"""ID of the integration you want to interact with."""


class DeleteHrisAbsencesAbsenceIDGlobals(BaseModel):
    integration_id: Annotated[
        Optional[str],
        pydantic.Field(alias="X-Integration-Id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""ID of the integration you want to interact with."""


class DeleteHrisAbsencesAbsenceIDRequestTypedDict(TypedDict):
    absence_id: str
    r"""The Kombo ID of the absence"""
    body: DeleteHrisAbsencesAbsenceIDRequestBodyTypedDict
    r"""DELETE /hris/absences/:absence_id Request body"""


class DeleteHrisAbsencesAbsenceIDRequest(BaseModel):
    absence_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The Kombo ID of the absence"""

    body: Annotated[
        DeleteHrisAbsencesAbsenceIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""DELETE /hris/absences/:absence_id Request body"""
